@@ -54,11 +54,14 @@ DEFAULT_SKIP: FrozenSet[str] = frozenset(
         ".hg",
         ".mypy_cache",
         ".nox",
+        ".svn",
+        ".bzr",
         "_build",
         "buck-out",
         "build",
         "dist",
         ".pants.d",
+        ".direnv",
         "node_modules",
     }
 )
@@ -132,6 +135,7 @@ class _Config:
     indent: str = " " * 4
     comment_prefix: str = "  #"
     length_sort: bool = False
+    length_sort_straight: bool = False
     length_sort_sections: FrozenSet[str] = frozenset()
     add_imports: FrozenSet[str] = frozenset()
     remove_imports: FrozenSet[str] = frozenset()
@@ -328,7 +332,7 @@ class Config(_Config):
                             f"Can't set both {key} and {section_name} in the same config file.\n"
                             f"Default to {section_name} if unsure."
                             "\n\n"
-                            "See: https://timothycrosley.github.io/isort/"
+                            "See: https://pycqa.github.io/isort/"
                             "#custom-sections-and-ordering."
                         )
                     else:
@@ -343,7 +347,7 @@ class Config(_Config):
                             f"`{key}` setting is defined, but {maps_to_section} is not"
                             " included in `sections` config option:"
                             f" {combined_config.get('sections', SECTION_DEFAULTS)}.\n\n"
-                            "See: https://timothycrosley.github.io/isort/"
+                            "See: https://pycqa.github.io/isort/"
                             "#custom-sections-and-ordering."
                         )
             if key.startswith(IMPORT_HEADING_PREFIX):
@@ -497,12 +501,13 @@ class Config(_Config):
             return self._known_patterns
 
         self._known_patterns = []
-        for placement in reversed(self.sections):
+        pattern_sections = [STDLIB] + [section for section in self.sections if section != STDLIB]
+        for placement in reversed(pattern_sections):
             known_placement = KNOWN_SECTION_MAPPING.get(placement, placement).lower()
             config_key = f"{KNOWN_PREFIX}{known_placement}"
             known_modules = getattr(self, config_key, self.known_other.get(known_placement, ()))
             extra_modules = getattr(self, f"extra_{known_placement}", ())
-            all_modules = set(known_modules).union(extra_modules)
+            all_modules = set(extra_modules).union(known_modules)
             known_patterns = [
                 pattern
                 for known_pattern in all_modules
@@ -522,14 +527,13 @@ class Config(_Config):
         self._section_comments = tuple(f"# {heading}" for heading in self.import_headings.values())
         return self._section_comments
 
-    @staticmethod
-    def _parse_known_pattern(pattern: str) -> List[str]:
+    def _parse_known_pattern(self, pattern: str) -> List[str]:
         """Expand pattern if identified as a directory and return found sub packages"""
         if pattern.endswith(os.path.sep):
             patterns = [
                 filename
-                for filename in os.listdir(pattern)
-                if os.path.isdir(os.path.join(pattern, filename))
+                for filename in os.listdir(os.path.join(self.directory, pattern))
+                if os.path.isdir(os.path.join(self.directory, pattern, filename))
             ]
         else:
             patterns = [pattern]
@@ -653,7 +657,9 @@ def _get_config_data(file_path: str, sections: Tuple[str]) -> Dict[str, Any]:
                     float("inf") if max_line_length == "off" else int(max_line_length)
                 )
             settings = {
-                key: value for key, value in settings.items() if key in _DEFAULT_SETTINGS.keys()
+                key: value
+                for key, value in settings.items()
+                if key in _DEFAULT_SETTINGS.keys() or key.startswith(KNOWN_PREFIX)
             }
 
         for key, value in settings.items():
